@@ -36,7 +36,7 @@ class Base:
         "name": "iMake",
         "org": "Snakypy Organization <https://github.com/snakypy>",
         "configuration_file": ".imake",
-        "version": "0.2.0",
+        "version": "0.3.0",
     }
 
 
@@ -123,7 +123,7 @@ class Main(Base):
         return args
 
 
-@denying_os("nt")
+@denying_os("Windows")
 def run():
     with suppress(TypeError):
 
